
## Product details

Combining tasteful details and durability, this minimalist Mainstays upholstered platform bed will transform your bedroom. Packed with modern style and traditional comfort from its bold geometric headboard and foam padded upholstered frame. It’s equipped with a metal slat platform made for supporting any mattress without the added box spring. Its framework is constructed with durable steel and center support legs that eliminate sagging and extend mattress life. In other words, your mattress will feel even dreamier on top of this dependable foundation. With all the parts, tools and instructions you’ll need to assemble with the help of a friend. Age Group: Adult, Universal.
Mainstays Upholstered Platform Bed, Queen
DURABLY DESIGNED - Interior steel framework and dense foam padding add comfort and longevity
NO BOX SPRING NEEDED - Durable metal slats support and extend the life of your latex, memory foam or spring mattress without the need for a box spring
HEIGHT ADJUSTABLE HEADBOARD - From 38" to 42" height for different mattress thickness
All parts, tools and instructions you’ll need to build the bed
Queen size supports a maximum weight capacity of 700 lbs
82 L x 63 W x 42 H Inches
Age Group: Adult, Universal.
Mattress sold separately
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Box spring required
N
Color
Gray
Height
7.87 in
Max load
700 lb
More details
## Warranty

Warranty information
1 Year Limited Warranty
